@@ -1,11 +1,11 @@
 #!/bin/sh
 echo 'name: xmonad-contrib
-version: 0.11
-id: xmonad-contrib-0.11-4bcc13e47c88bd84134572f3ff7614be
+version: 0.11.1
+id: xmonad-contrib-0.11.1-be9730211610031cf7c82c803edc42e6
 
 license: BSD3
 copyright:
-maintainer: spencerjanssen@gmail.com
+maintainer: xmonad@haskell.org
 stability:
 homepage: http://xmonad.org/
 package-url:
@@ -24,7 +24,7 @@ description: Third party tiling algorithms, configurations and scripts to xmonad
              your own extensions.
              .
 category: System
-author: Spencer Janssen
+author: Spencer Janssen & others
 pkgpath: x11/hs-xmonad-contrib
 exposed: True
 exposed-modules: XMonad.Doc XMonad.Doc.Configuring
@@ -133,32 +133,32 @@ exposed-modules: XMonad.Doc XMonad.Doc.Configuring
                  XMonad.Util.XUtils
 hidden-modules:
 trusted: False
-import-dirs: /usr/local/lib/ghc/xmonad-contrib-0.11
-library-dirs: /usr/local/lib/ghc/xmonad-contrib-0.11
-hs-libraries: HSxmonad-contrib-0.11
+import-dirs: /usr/local/lib/ghc/xmonad-contrib-0.11.1
+library-dirs: /usr/local/lib/ghc/xmonad-contrib-0.11.1
+hs-libraries: HSxmonad-contrib-0.11.1
 extra-libraries:
 extra-ghci-libraries:
 include-dirs:
 includes:
-depends: X11-1.6.0-30a3138c90d76e3cd65f9756d31a2870
-         X11-xft-0.3.1-d523c9e40af5b50239f723c6699edeb8
-         base-4.5.1.0-f38bf31a759416ec7b167d6dc132959a
-         containers-0.4.2.1-75f143aa39a3e77a1ce2300025bdd8ce
-         directory-1.1.0.2-da0a8c62c2b42ae7a3b538f5fee58422
-         extensible-exceptions-0.1.1.4-3d9bd197c43329612c640f24179a7f19
-         mtl-2.1.2-02e701f9b1590ee88a0b5b0bd5d93a29
-         old-locale-1.0.0.4-5e45cabd3b4fdcad9e353ea3845f5ef7
-         old-time-1.1.0.0-c11d19d5710541e7a9ae41c1582972eb
-         process-1.1.0.1-608c248c1528f46eb960a08cead77291
-         random-1.0.1.1-d8f82f84701874725b418c29860a58e0
-         unix-2.5.1.1-0adea5be633a6b5a124519287d54626d
-         utf8-string-0.3.8-2777416918ab74e3e486858d8ef2fdf6
-         xmonad-0.11-bce530df3a23a2e9ed80757b0d9a6c62
+depends: X11-1.6.1.1-4a4f242486ab0f5871a70bcb05fc9b64
+         X11-xft-0.3.1-aad3a1a9e973718d34f37399334e9780
+         base-4.6.0.1-03845c6da2a0b3b4d0d49cc26c0cd3c0
+         containers-0.5.0.0-ab1dae9a94cd3cc84e7b2805636ebfa2
+         directory-1.2.0.1-ee04c884b72040489d2e2ca6dd62e6ac
+         extensible-exceptions-0.1.1.4-255a395b3b026cb94b23754e1c372785
+         mtl-2.1.2-94c72af955e94b8d7b2f359dadd0cb62
+         old-locale-1.0.0.5-6729cb9d9cc62d150655de8fc5401b91
+         old-time-1.1.0.1-029c40e673a46f6084b935f654a6fa28
+         process-1.1.0.2-76e05340eb66705981411022731ca84a
+         random-1.0.1.1-023a342365721422ffd5a919bc8708bb
+         unix-2.6.0.1-2939d4be83b53d31ca104e0487b1ef98
+         utf8-string-0.3.8-ac107fb901621046f538bc29451f9d70
+         xmonad-0.11-06d49a013633b28f09c16abbbaf31abb
 hugs-options:
 cc-options:
 ld-options:
 framework-dirs:
 frameworks:
-haddock-interfaces: /usr/local/share/doc/hs-xmonad-contrib-0.11/html/xmonad-contrib.haddock
-haddock-html: /usr/local/share/doc/hs-xmonad-contrib-0.11/html
-' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-conf' "$@"
+haddock-interfaces: /usr/local/share/doc/hs-xmonad-contrib-0.11.1/html/xmonad-contrib.haddock
+haddock-html: /usr/local/share/doc/hs-xmonad-contrib-0.11.1/html
+' | '/usr/local/bin/ghc-pkg' 'update' '-' '--global' '--no-user-package-db' "$@"
